@@ -1,11 +1,13 @@
 """Tools module."""
 from . import build_shapegrid
+from . import calculate_pam_stats
 from . import clean_occurrences
 from . import convert_csv_to_lmm
 from . import convert_lmm_to_csv
 from . import create_rare_species_model
 from . import create_tree_matrix
 from . import encode_layers
+from . import mcpa_run
 from . import randomize_pam
 from . import split_occurrence_data
 from . import wrangle_matrix
@@ -13,12 +15,14 @@ from . import wrangle_tree
 
 __all__ = []
 __all__.extend(build_shapegrid.__all__)
+__all__.extend(calculate_pam_stats.__all__)
 __all__.extend(clean_occurrences.__all__)
 __all__.extend(convert_csv_to_lmm.__all__)
 __all__.extend(convert_lmm_to_csv.__all__)
 __all__.extend(create_rare_species_model.__all__)
 __all__.extend(create_tree_matrix.__all__)
 __all__.extend(encode_layers.__all__)
+__all__.extend(mcpa_run.__all__)
 __all__.extend(randomize_pam.__all__)
 __all__.extend(split_occurrence_data.__all__)
 __all__.extend(wrangle_matrix.__all__)
